@@ -4,9 +4,17 @@ $(function () {
       url: "/buybackprogram/item_autocomplete/",
     },
   });
-$("#id_eve_solar_system").autoComplete({
+
+  $("#id_eve_solar_system").autoComplete({
     resolverSettings: {
       url: "/buybackprogram/solarsystem_autocomplete/",
     },
   });
+
+  $("#id_marketgroup").autoComplete({
+    resolverSettings: {
+      url: "/buybackprogram/marketgroup_autocomplete/",
+    },
+  });
+
 });
